BeanError

Enum BeanError 

#[non_exhaustive]
pub enum BeanError { Amount(AmountError), Currency(CurrencyError), Money(MoneyError), AccountCode(AccountCodeError), AccountType(AccountTypeError), DebitCredit(DebitCreditError), Entry(EntryError), Transaction(TransactionError), }
Top-level error type aggregating all domain errors in the crate.

Each variant wraps a specific domain error, allowing callers to use the ? operator with any beankeeper operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Amount(AmountError)

An error from monetary amount operations.



Currency(CurrencyError)

An error from currency operations.



Money(MoneyError)

An error from money operations.



AccountCode(AccountCodeError)

An error from account code validation.



AccountType(AccountTypeError)

An error from account type parsing.



DebitCredit(DebitCreditError)

An error from debit/credit parsing.



Entry(EntryError)

An error from entry construction.



Transaction(TransactionError)

An error from transaction validation.